%define	_root_sbindir	/sbin
%define	_root_libdir	/%{_lib}
%define	major	2
%define libname %mklibname ext2fs %{major}
%define	devname	%mklibname ext2fs -d

%define git_url git://git.kernel.org/pub/scm/fs/ext2/e2fsprogs.git

%bcond_without	uclibc

Name:		e2fsprogs
Version:	1.42.6
Release:	4
Summary:	Utilities used for ext2/ext3/ext4 filesystems
License:	GPLv2
Group:		System/Kernel and hardware
Source0:	http://downloads.sourceforge.net/e2fsprogs/e2fsprogs-%version.tar.gz
Source1:	e3jsize
# (anssi) fix uninitialized variable causing crash without libreadline.so.5;
# submitted as https://sourceforge.net/tracker/?func=detail&aid=2822113&group_id=2406&atid=302406
Patch0:		e2fsprogs-1.41.8-uninitialized.patch
# (gb) strip references to home build dir
Patch5:		e2fsprogs-1.41.8-strip-me.patch

Url:		http://e2fsprogs.sourceforge.net/
BuildRequires:	texinfo autoconf
BuildRequires:	pkgconfig(blkid)
BuildRequires:	pkgconfig(uuid)
%if %{with uclibc}
BuildRequires:	uClibc-devel >= 0.9.33.2-16
%endif
Conflicts:	e2fsprogs < 1.42.6-4

%description
The e2fsprogs package contains a number of utilities for creating,
checking, modifying and correcting any inconsistencies in ext2, ext3,
and ext4 filesystems.  E2fsprogs contains e2fsck (used to repair
filesystem inconsistencies after an unclean shutdown), mke2fs (used to
initialize a partition to contain an empty ext2 filesystem), debugfs
(used to examine the internal structure of a filesystem, to manually
repair a corrupted filesystem or to create test cases for e2fsck), tune2fs
(used to modify filesystem parameters), resize2fs to grow and shrink
unmounted filesystems, and most of the other core ext2fs filesystem
utilities.

%package -n	uclibc-%{name}
Summary:	Utilities used for ext2/ext3/ext4 filesystems (uClibc linked)
Group:		System/Kernel and hardware

%description -n	uclibc-%{name}
The e2fsprogs package contains a number of utilities for creating,
checking, modifying and correcting any inconsistencies in ext2, ext3,
and ext4 filesystems.  E2fsprogs contains e2fsck (used to repair
filesystem inconsistencies after an unclean shutdown), mke2fs (used to
initialize a partition to contain an empty ext2 filesystem), debugfs
(used to examine the internal structure of a filesystem, to manually
repair a corrupted filesystem or to create test cases for e2fsck), tune2fs
(used to modify filesystem parameters), resize2fs to grow and shrink
unmounted filesystems, and most of the other core ext2fs filesystem
utilities.

%package -n	%{libname}
Summary:	The libraries for Ext2fs
Group:		System/Libraries

%description -n %{libname}
The e2fsprogs package contains a number of utilities for creating,
checking, modifying and correcting any inconsistencies in ext2, ext3,
and ext4 filesystems.  E2fsprogs contains e2fsck (used to repair
filesystem inconsistencies after an unclean shutdown), mke2fs (used to
initialize a partition to contain an empty ext2 filesystem), debugfs
(used to examine the internal structure of a filesystem, to manually
repair a corrupted filesystem or to create test cases for e2fsck), tune2fs
(used to modify filesystem parameters), resize2fs to grow and shrink
unmounted filesystems, and most of the other core ext2fs filesystem
utilities.

This package contains the shared libraries.

%package -n	uclibc-%{libname}
Summary:	The libraries for Ext2fs (uClibc linked)
Group:		System/Libraries

%description -n uclibc-%{libname}
The e2fsprogs package contains a number of utilities for creating,
checking, modifying and correcting any inconsistencies in ext2, ext3,
and ext4 filesystems.  E2fsprogs contains e2fsck (used to repair
filesystem inconsistencies after an unclean shutdown), mke2fs (used to
initialize a partition to contain an empty ext2 filesystem), debugfs
(used to examine the internal structure of a filesystem, to manually
repair a corrupted filesystem or to create test cases for e2fsck), tune2fs
(used to modify filesystem parameters), resize2fs to grow and shrink
unmounted filesystems, and most of the other core ext2fs filesystem
utilities.

%package -n	%{devname}
Summary:	The libraries for Ext2fs
Group:		Development/C
Requires:	%{libname} = %{EVRD}
%if %{with uclibc}
Requires:	uclibc-%{libname} = %{EVRD}
%endif
Provides:	ext2fs-devel = %{EVRD}

%description -n	%{devname}
The e2fsprogs package contains a number of utilities for creating,
checking, modifying and correcting any inconsistencies in ext2, ext3,
and ext4 filesystems.  E2fsprogs contains e2fsck (used to repair
filesystem inconsistencies after an unclean shutdown), mke2fs (used to
initialize a partition to contain an empty ext2 filesystem), debugfs
(used to examine the internal structure of a filesystem, to manually
repair a corrupted filesystem or to create test cases for e2fsck), tune2fs
(used to modify filesystem parameters), resize2fs to grow and shrink
unmounted filesystems, and most of the other core ext2fs filesystem
utilities.

You should install %{libname} to use tools that compile with ext2fs
features.

%prep
%setup -q
%patch0 -p1 -b .uninit
%patch5 -p1 -b .strip-me

rm -f configure
autoconf

# Fix build:
chmod 644 po/*.po

%build
export CONFIGURE_TOP="$PWD"

%if %{with uclibc}
mkdir -p uclibc
pushd uclibc
%uclibc_configure \
		--enable-elf-shlibs \
		--disable-libblkid \
		--disable-libuuid \
		--disable-fsck \
		--disable-uuidd \
		--enable-symlink-install \
		--disable-e2initrd-helper
%make
%make -C e2fsck
popd
%endif

mkdir -p system
pushd system
%configure2_5x	--enable-elf-shlibs \
		--disable-libblkid \
		--disable-libuuid \
		--disable-fsck \
		--disable-uuidd \
		--enable-symlink-install
%make
%make -C e2fsck e2fsck.static
popd

#%check
#LC_ALL=C make -C system check -k || /bin/true

%install
export PATH=/sbin:$PATH

%if %{with uclibc}
%makeinstall_std -C uclibc install-libs \
		root_sbindir=%{uclibc_root}/sbin \
		root_libdir=%{uclibc_root}/%{_lib}
rm -r %{buildroot}%{uclibc_root}%{_libdir}/pkgconfig
for bin in chattr compile_et lsattr mk_cmds; do
	rm %{buildroot}%{uclibc_root}%{_bindir}/$bin
done
%endif

%makeinstall_std -C system install-libs \
	root_sbindir=%{_root_sbindir} root_libdir=%{_root_libdir}

# multiarch policy, alternative is to use <stdint.h>
%multiarch_includes %{buildroot}%{_includedir}/ext2fs/ext2_types.h

%find_lang %{name}

chmod +x %{buildroot}%{_bindir}/{mk_cmds,compile_et}

install -m 755 system/e2fsck/e2fsck.static %{buildroot}%{_root_sbindir}
install -m 755 %{SOURCE1} %{buildroot}%{_root_sbindir}
ln -f %{buildroot}%{_root_sbindir}/mke2fs \
	%{buildroot}%{_root_sbindir}/mke3fs

# fix some files not having write permission by user
chmod u+w -R %{buildroot}

%files -f %{name}.lang
%doc README
%{_root_sbindir}/badblocks
%{_root_sbindir}/debugfs
%{_root_sbindir}/dumpe2fs
%{_root_sbindir}/e2fsck
%{_root_sbindir}/e2fsck.static
%{_root_sbindir}/e2image
%{_root_sbindir}/e2label
%{_root_sbindir}/e2undo
%{_root_sbindir}/e3jsize
%{_root_sbindir}/fsck.ext2
%{_root_sbindir}/fsck.ext3
%{_root_sbindir}/fsck.ext4
%{_root_sbindir}/fsck.ext4dev
%{_root_sbindir}/logsave
%{_root_sbindir}/mke2fs
%{_root_sbindir}/mke3fs
%{_root_sbindir}/mkfs.ext2
%{_root_sbindir}/mkfs.ext3
%{_root_sbindir}/mkfs.ext4
%{_root_sbindir}/mkfs.ext4dev
%{_root_sbindir}/resize2fs
%{_root_sbindir}/tune2fs
%config(noreplace) %{_sysconfdir}/mke2fs.conf
%{_libexecdir}/e2initrd_helper

%{_bindir}/chattr
%{_bindir}/lsattr
%{_mandir}/man1/chattr.1*
%{_mandir}/man1/lsattr.1*
%{_mandir}/man5/e2fsck.conf.5*
%{_mandir}/man5/mke2fs.conf.5*
%{_mandir}/man8/badblocks.8*
%{_mandir}/man8/debugfs.8*
%{_mandir}/man8/dumpe2fs.8*
%{_mandir}/man8/e2freefrag.8*
%{_mandir}/man8/e2fsck.8*
%{_mandir}/man8/e2image.8*
%{_mandir}/man8/e2label.8*
%{_mandir}/man8/e2undo.8.*
%{_mandir}/man8/e4defrag.8.*
%{_mandir}/man8/filefrag.8*
%{_mandir}/man8/fsck.ext2.8*
%{_mandir}/man8/fsck.ext3.8*
%{_mandir}/man8/fsck.ext4.8.*
%{_mandir}/man8/fsck.ext4dev.8.*
%{_mandir}/man8/logsave.8*
%{_mandir}/man8/mke2fs.8*
%{_mandir}/man8/mkfs.ext2.8*
%{_mandir}/man8/mkfs.ext3.8*
%{_mandir}/man8/mkfs.ext4.8.*
%{_mandir}/man8/mkfs.ext4dev.8.*
%{_mandir}/man8/mklost+found.8*
%{_mandir}/man8/resize2fs.8*
%{_mandir}/man8/tune2fs.8*
%{_sbindir}/e2freefrag
%{_sbindir}/e4defrag
%{_sbindir}/filefrag
%{_sbindir}/mklost+found

%if %{with uclibc}
%files -n uclibc-%{name}
%{uclibc_root}/sbin/badblocks
%{uclibc_root}/sbin/debugfs
%{uclibc_root}/sbin/dumpe2fs
%{uclibc_root}/sbin/e2fsck
%{uclibc_root}/sbin/e2image
%{uclibc_root}/sbin/e2label
%{uclibc_root}/sbin/e2undo
%{uclibc_root}/sbin/fsck.ext2
%{uclibc_root}/sbin/fsck.ext3
%{uclibc_root}/sbin/fsck.ext4
%{uclibc_root}/sbin/fsck.ext4dev
%{uclibc_root}/sbin/logsave
%{uclibc_root}/sbin/mke2fs
%{uclibc_root}/sbin/mkfs.ext2
%{uclibc_root}/sbin/mkfs.ext3
%{uclibc_root}/sbin/mkfs.ext4
%{uclibc_root}/sbin/mkfs.ext4dev
%{uclibc_root}/sbin/resize2fs
%{uclibc_root}/sbin/tune2fs
%{uclibc_root}%{_sbindir}/e2freefrag
%{uclibc_root}%{_sbindir}/e4defrag
%{uclibc_root}%{_sbindir}/filefrag
%{uclibc_root}%{_sbindir}/mklost+found
%endif

%files -n %{libname}
%doc README
%{_root_libdir}/libcom_err.so.%{major}*
%{_root_libdir}/libe2p.so.%{major}*
%{_root_libdir}/libext2fs.so.%{major}*
%{_root_libdir}/libss.so.%{major}*

%if %{with uclibc}
%files -n uclibc-%{libname}
%doc README
%{uclibc_root}/%{_lib}/libcom_err.so.%{major}*
%{uclibc_root}/%{_lib}/libe2p.so.%{major}*
%{uclibc_root}/%{_lib}/libext2fs.so.%{major}*
%{uclibc_root}/%{_lib}/libss.so.%{major}*
%endif

%files -n %{devname}
%doc RELEASE-NOTES
%{_infodir}/libext2fs.info*
%{_bindir}/compile_et
%{_mandir}/man1/compile_et.1*
%{_bindir}/mk_cmds
%{_mandir}/man1/mk_cmds.1*
%{_libdir}/pkgconfig/*

%{_libdir}/libcom_err.so
%{_libdir}/libe2p.a
%{_libdir}/libe2p.so
%{_libdir}/libext2fs.a
%{_libdir}/libext2fs.so
%{_libdir}/libcom_err.a
%{_libdir}/libquota.a
%{_libdir}/libss.a
%{_libdir}/libss.so

%if %{with uclibc}
%{uclibc_root}%{_libdir}/libcom_err.so
%{uclibc_root}%{_libdir}/libe2p.a
%{uclibc_root}%{_libdir}/libe2p.so
%{uclibc_root}%{_libdir}/libext2fs.a
%{uclibc_root}%{_libdir}/libext2fs.so
%{uclibc_root}%{_libdir}/libcom_err.a
%{uclibc_root}%{_libdir}/libquota.a
%{uclibc_root}%{_libdir}/libss.a
%{uclibc_root}%{_libdir}/libss.so
%endif

%{_datadir}/et
%{_datadir}/ss
%{_includedir}/com_err.h
%{_includedir}/et
%{_includedir}/ext2fs
%dir %{multiarch_includedir}/ext2fs
%{multiarch_includedir}/ext2fs/ext2_types.h
%dir %{_includedir}/quota
%{_includedir}/quota/mkquota.h
%{_includedir}/ss
%dir %{_includedir}/e2p
%{_includedir}/e2p/e2p.h
%{_mandir}/man3/com_err.3*


%changelog
* Sun Oct 28 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.42.6-4
+ Revision: 820160
- just pass --disable-e2initrd-helper to configure for uclibc build so we won't
  have to manually delete it later ourself
- move e2initrd_helper to main package from library package
- don't remove libss.a
- fix uClibc build's file list

* Tue Oct 16 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 1.42.6-3
+ Revision: 818938
- reupload

* Tue Oct 16 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.42.6-2
+ Revision: 818883
- rebuild to get uclibc deps right

* Sun Oct 07 2012 Alexander Khrukin <akhrukin@mandriva.org> 1.42.6-1
+ Revision: 818670
- version update 1.42.6

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - try skipping %%check entirely..
    - don't let check suite which fails on build system break build
    - do uClibc build

* Thu Aug 16 2012 Alexander Khrukin <akhrukin@mandriva.org> 1.42.5-1
+ Revision: 814981
- version update 1.42.5

* Thu Jun 14 2012 Alexander Khrukin <akhrukin@mandriva.org> 1.42.4-1
+ Revision: 805664
- version update 1.42.4

* Tue May 15 2012 Bernhard Rosenkraenzer <bero@bero.eu> 1.42.3-1
+ Revision: 799022
- Update to 1.42.3

* Wed Mar 28 2012 Bernhard Rosenkraenzer <bero@bero.eu> 1.42.2-1
+ Revision: 788040
- Update to 1.42.2
- Adapt spec file to current rpm macros

* Wed Feb 22 2012 Bernhard Rosenkraenzer <bero@bero.eu> 1.42.1-1
+ Revision: 779240
- Upate to 1.42.1

* Fri Dec 23 2011 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.42-1
+ Revision: 744672
- use %%{EVRD} macro
- drop excessive provides and ancient obsoletes
- make config file %%config(noreplace)
- library package shouldn't depend on e2fsprogs
- use pkgconfig() dependencies
- specify gpl version
- new version!
- be sure to own %%{_includedir}/e2p
- cleanups!

* Mon May 02 2011 Oden Eriksson <oeriksson@mandriva.com> 1.41.14-2
+ Revision: 661660
- multiarch fixes

* Thu Dec 23 2010 Funda Wang <fwang@mandriva.org> 1.41.14-1mnb2
+ Revision: 624064
- new version 1.41.14
- new version 1.41.13
- use symbolic link rather than hardlink

* Fri Jun 11 2010 Thomas Backlund <tmb@mandriva.org> 1.41.12-1mnb2
+ Revision: 547931
- update to 1.41.12 (bugfix release)

* Tue Mar 16 2010 Funda Wang <fwang@mandriva.org> 1.41.11-1mnb2
+ Revision: 522506
- New version 1.41.11

* Sat Feb 27 2010 Thomas Backlund <tmb@mandriva.org> 1.41.10-2mnb2
+ Revision: 512296
- rebuild against new libblkid)

* Thu Feb 11 2010 Frederik Himpe <fhimpe@mandriva.org> 1.41.10-1mnb2
+ Revision: 504356
- Update to new version 1.41.10
- Does not ship with a default e2fsck.conf anymore

* Wed Oct 07 2009 Thierry Vignaud <tv@mandriva.org> 1.41.9-2mnb2
+ Revision: 455479
- move huge doc in devel package

* Sun Aug 23 2009 Frederik Himpe <fhimpe@mandriva.org> 1.41.9-1mnb2
+ Revision: 419892
- Update to new version 1.41.9

* Tue Aug 04 2009 Frederic Crozat <fcrozat@mandriva.com> 1.41.8-3mnb2
+ Revision: 408789
- Rebuild against libuuid
- disable libuuid-devel deps for bootstrapping

  + Eugeni Dodonov <eugeni@mandriva.com>
    - Disable libuuid and fsck (now handled by util-linux-ng).

* Wed Jul 15 2009 Anssi Hannula <anssi@mandriva.org> 1.41.8-1mnb2
+ Revision: 396478
- fix crash without libreadline.so.5 (uninitialized.patch)
- rediff strip-me.patch
- update summaries and descriptions to mention ext3, ext4, resize2fs

  + Thierry Vignaud <tv@mandriva.org>
    - new release

  + Frederik Himpe <fhimpe@mandriva.org>
    - update to new version 1.41.7

* Tue Jun 09 2009 Frederic Crozat <fcrozat@mandriva.com> 1.41.6-3mnb2
+ Revision: 384246
- Rebuild against libblkid
- ensure tests pass on x86_64 too
- Enable parallel build
- Add git_url

* Mon Jun 08 2009 Frederic Crozat <fcrozat@mandriva.com> 1.41.6-2mnb2
+ Revision: 384074
- Do not build libblkid (shipped by util-linux-ng now)
- Remove patch36 (obsolete)
- Temporary buildrequires libext2fs-devel, to be able to install libblkid-devel

* Sat May 30 2009 Frederik Himpe <fhimpe@mandriva.org> 1.41.6-1mnb2
+ Revision: 381530
- update to new version 1.41.6

* Mon May 04 2009 Thierry Vignaud <tv@mandriva.org> 1.41.5-1mnb2
+ Revision: 371725
- new release

* Mon Feb 09 2009 Thierry Vignaud <tv@mandriva.org> 1.41.4-1mnb2
+ Revision: 338875
- new release
- drop patches 10, 67, 68 & 69 (merged upstream)
- add more upstrem commited annotations

* Wed Jan 21 2009 Thierry Vignaud <tv@mandriva.org> 1.41.3-3mnb2
+ Revision: 332252
- drop patch 9 (istat support), now useless with new e3jsize
- drop patch8 and package e2fsck.conf so that fsck doesn't force fsck on first
  reboot tue to timezone issues
- update patches 10, 68 & 69 according to Theodore Tso's comments
  (add commited upstreama annotations)
- e3jsize: use standard 'stat' command instead of turbolinux 'istat' extension
- drop patch 4: old useless auconf bit from redhat (november 2001!)
- drop patch 66: now useless (and was dropped by fedora too)

* Tue Jan 20 2009 Thierry Vignaud <tv@mandriva.org> 1.41.3-2mnb2
+ Revision: 331878
- temporary enable fuzzy patches
- drop most redhat patches introduced in r63796 on 2007-08-15 since:
  o they were removed from redhat
  o patch 30 ("enable tune2fs to set and clear the resize inode (#167816)")
  	allows tune2fs to set the resize_inode feature without actually creating
  	the resize inode --- this leads to a corrupted filesystem, which is
  	generally not considered a good thing
- drop patch 7: no more needed
- patch 69: fix build with Werror_format=security

* Thu Oct 16 2008 Thierry Vignaud <tv@mandriva.org> 1.41.3-1mnb2
+ Revision: 294293
- new release

* Thu Oct 02 2008 Thierry Vignaud <tv@mandriva.org> 1.41.2-1mnb2
+ Revision: 290859
- new release

* Tue Sep 09 2008 Pixel <pixel@mandriva.com> 1.41.1-2mnb2
+ Revision: 283112
- handle mkfs.ext3 -U <UUID>

* Tue Sep 02 2008 Thierry Vignaud <tv@mandriva.org> 1.41.1-1mnb2
+ Revision: 278895
- rediff patch 66
- rediff patch 36
- remove patch 10 (merged upstream)
- new release

* Mon Aug 25 2008 Olivier Blin <blino@mandriva.org> 1.41.0-2mnb2
+ Revision: 275686
- fix probing logic in blkid to find renamed devices (#43146)

* Tue Jul 22 2008 Thierry Vignaud <tv@mandriva.org> 1.41.0-1mnb2
+ Revision: 240354
- new release
- kill merged patch #10
- rediff patch 39
- sort file list

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Apr 22 2008 Makoto Dei <makoto@turbolinux.co.jp> 1.40.8-2mnb1
+ Revision: 196411
- fix the bug that fsck didn't accept the 'j' with German locale (#39803)

* Mon Mar 17 2008 Thierry Vignaud <tv@mandriva.org> 1.40.8-1mnb1
+ Revision: 188431
- new release (fix resizing)
- rediff patch 62
- new release

* Wed Feb 27 2008 Makoto Dei <makoto@turbolinux.co.jp> 1.40.6-3mnb1
+ Revision: 175693
- fix the bug that mke3fs doesn't create journal

* Sun Feb 24 2008 Andrey Borzenkov <arvidjaar@mandriva.org> 1.40.6-2mnb1
+ Revision: 174456
- patch67: add support for user level suspend in libblkid

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 1.40.6-1mnb1
+ Revision: 171225
- replace %%mkrel with %%manbo_mkrel for Manbo Core 1

* Tue Feb 12 2008 Thierry Vignaud <tv@mandriva.org> 1.40.6-1mdv2008.1
+ Revision: 166818
- new release

* Fri Feb 08 2008 Makoto Dei <makoto@turbolinux.co.jp> 1.40.5-3mdv2008.1
+ Revision: 164069
- Manbo-Lab
- added static link version of e2fsck (/sbin/e2fsck.static)
- added /sbin/mke3fs which is a link to /sbin/mke2fs
- added istat command to debugfs to show inode information
- added /sbin/e3jsize which is a shell script to show journal size of ext3 fs

* Wed Feb 06 2008 Olivier Blin <blino@mandriva.org> 1.40.5-2mdv2008.1
+ Revision: 163016
- create /etc/blkid, so that blkid can create blkid.tab

* Mon Jan 28 2008 Thierry Vignaud <tv@mandriva.org> 1.40.5-1mdv2008.1
+ Revision: 159273
- kill merged patches 9, 34 & 63
- new release
- new release

* Fri Jan 11 2008 Pixel <pixel@mandriva.com> 1.40.4-4mdv2008.1
+ Revision: 147904
- ensure vol_id and blkid returns the same UUID on ntfs (#36144)

* Tue Jan 08 2008 Thierry Vignaud <tv@mandriva.org> 1.40.4-3mdv2008.1
+ Revision: 146448
- revert bogus "version Requires/Obsoletes/Providesr" change (part of r82504 from
  walluck on 2007-09-08) that break updating some biarch systems
- remove testsuite hack

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

* Wed Jan 02 2008 Thierry Vignaud <tv@mandriva.org> 1.40.4-2mdv2008.1
+ Revision: 140477
- new release
- kill re-definition of %%buildroot on Pixel's request

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - protect ->open ops from glibc open-create-mode-checker (P66 from fedora)

* Tue Dec 11 2007 Thierry Vignaud <tv@mandriva.org> 1.40.3-1mdv2008.1
+ Revision: 117365
- set PATH so that make lib/ss test pass
- rediff patch 62
- kill patch 64 (merged upstream)
- revert r115880 (2007-12-06) from peroyvind ("sync with fedora patches")
  since there're no such patches
- new release

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - can now be safely built with optimizations, do so
    - sync with fedora patches

* Sun Sep 16 2007 Funda Wang <fwang@mandriva.org> 1.40.2-5mdv2008.0
+ Revision: 87931
- really obsoletes old devel package

* Sat Sep 08 2007 David Walluck <walluck@mandriva.org> 1.40.2-4mdv2008.0
+ Revision: 82504
- version Requires/Obsoletes/Provides
- Provides: ext2fs-devel = %%{version}-%%{release}
- release 3 claimed to implement the new devel policy but didn't, so implement it

* Wed Aug 15 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.40.2-3mdv2008.0
+ Revision: 63835
- sync with fedora patches
- new devel policy
- fix uninstall of info pages at correct stage

* Tue Aug 07 2007 David Walluck <walluck@mandriva.org> 1.40.2-2mdv2008.0
+ Revision: 59593
- move %%_mandir/man3/libblkid.3* to devel package to fix multiarch conflict

* Thu Aug 02 2007 Thierry Vignaud <tv@mandriva.org> 1.40.2-1mdv2008.0
+ Revision: 58198
- new release

* Thu Aug 02 2007 Olivier Blin <blino@mandriva.org> 1.40-3mdv2008.0
+ Revision: 57902
- fix last check problem index (it used the same index as the dirhash hint, thus causing havoc in e2fsck, and secondarily breaking tests and rpm build)
- rebuild for new kernel headers (__u64 and __s64 types have changed)
- make files list extension-agnostic for man pages (fix build with lzma man pages)

  + David Walluck <walluck@mandriva.org>
    - 1.40
    - remove fix-memleak patch (fixed upstream)

* Thu Jun 14 2007 Thierry Vignaud <tv@mandriva.org> 1.39-5mdv2008.0
+ Revision: 39781
- patch 9: fix mem leak in libblkid (#31295)
- patch 9: fix mem leak in libblkid (#31295)


* Sun Jan 07 2007 David Walluck <walluck@mandriva.org> 1.39-4mdv2007.0
+ Revision: 104996
- bump release
- remove redundant autoconf call
  force %%check to pass on x86_64 for now (2 test failures)
- rebuild
  bunzip2 patches
  add %%check section

  + Emmanuel Andry <eandry@mandriva.org>
    - Import e2fsprogs

* Wed Aug 23 2006 Pixel <pixel@mandriva.com> 1.39-2mdv2007.0
- DrakX doesn't set the timezone/utc before formatting partition, 
  resulting in check time in the future, and so a forced fsck
  at first boot. fixing this.

* Fri Jun 23 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.39-1mdv2007.0
- new release
- drop patch 6 (no more needed)

* Mon May 15 2006 Stefan van der Eijk <stefan@eijk.nu> 1.38-5mdk
- rebuild for sparc

* Thu Oct 20 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.38-4mdk
- fortify fixes

* Sat Sep 10 2005 Olivier Blin <oblin@mandriva.com> 1.38-3mdk
- fix typo in summaries

* Tue Sep 06 2005 Thierry Vignaud <tvignaud@mandriva.com> 1.38-2mdk
- fix running tests

* Fri Aug 05 2005 Thierry Vignaud <tvignaud@mandriva.com> 1.38-1mdk
- new release
- drop patch 6 (merged upstream)
- rediff patch 7

* Mon Aug 01 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.37-5mdk
- patch 7: fix compilation of libs/e2p/os_type

* Sun Jul 31 2005 Nicolas Lcureuil <neoclust@mandriva.org> 1.37-4mdk
- Use a better BuildRequires as explain by Blino

* Sun Jul 31 2005 Nicolas Lcureuil <neoclust@mandriva.org> 1.37-3mdk
- Fix BuildRequires

* Thu Jul 28 2005 Thierry Vignaud <tvignaud@mandriva.com> 1.37-2mdk
- patch 6: fix segfault in e2fsck

* Sat May 14 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.37-1mdk
- new release

* Sun Mar 06 2005 Stefan van der Eijk <stefan@eijk.nu> 1.36-3mdk
- reupload

* Mon Feb 28 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.36-2mdk
- don't reference home build dirs in compile_et and mk_cmds (multiarch)
- other multiarch fixes, though it could be fixed differently with <stdint.h>

* Fri Feb 11 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.36-1mdk
- new release
- rediff patch 4

* Thu Apr 01 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.35-1mdk
- new release
- remove patch 6 (no more needed)

* Thu Feb 26 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.34-5mdk
- patch 6: fix build
- rpmlint fix

* Mon Jan 12 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.34-4mdk
- fix perms

